import 'dart:async';
import 'dart:io';

import 'package:connectycube_sdk/connectycube_calls.dart';
import 'package:connectycube_sdk/connectycube_core.dart';
import 'package:connectycube_sdk/src/calls/conference/conference_client.dart';
import 'package:connectycube_sdk/src/calls/signaling/web_socket_connection.dart';
import 'package:connectycube_sdk/src/calls/signaling/web_socket_packets.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:web_socket_channel/io.dart';
import 'package:web_socket_channel/status.dart' as status;

Future<void> createSession() {
  Completer completer = Completer<void>();
  var client = ConferenceClient.instance;
  client.createCallSession(500).then((voidValue) {
    logTime("createSession OK");
    completer.complete();
  }).catchError((onError) {
    logTime("createSession onError= $onError");
    completer.complete();
  });
  return completer.future;
}

void main() {
  ConferenceConfig.instance.url = "";
  test('connect', () async {
    return await Future.value(createSession);
  });
  sleep(const Duration(seconds: 10));
  logTime("Done!");
}

Future<void> connect() {
  Completer completer = Completer<void>();
  sleep(const Duration(seconds: 3));
  var channel = IOWebSocketChannel.connect('ws://echo.websocket.org');
  channel.sink.add("connected!");
  channel.stream.listen((message) {
    logTime("Connection onMessage message= ${message}");
    completer.complete();
  }, onError: (err) {
    logTime("Connection onError err= ${err}");
  });
  return completer.future;
}
